@@ -402,29 +402,28 @@ class Context:
         p.config = {k: v for k, v in config.items()
                     if k in p.takes_config}
 
-        if p.child_ends_with:
-            # This plugin is a child of another plugin and has some different
-            # Checking if the parent plugin is registered, this does not have to be the case
-            # but enables some useful checks.
-            parent_class = self._plugin_class_registry[p.provides[-1]].__bases__[0]
-            is_parent_reg = parent_class in self._plugin_class_registry.values()
+        if p.child_plugin:
+            # This plugin is a child of another plugin. This means we have to overwrite
+            # the registered option settings in p.config with the options specified by the
+            # child. This is required since the super().compute() method in a child plugins
+            # will still point to the option names of the parent (e.g. self.config['parent_name']).
+
             # options to pass. So update parent config according to child:
-            for k, opt in p.takes_config.items():
-                if k.endswith(p.child_ends_with):
-                    if opt.child_option:
-                        v = config[k]
-                        kparent = k[:-len(p.child_ends_with)]
+            for option_name, opt in p.takes_config.items():
+                # Now loop again overall options for this plugin (parent + child)
+                # and get all child options:
+                if opt.child_option:
+                    # See if option is tagged as a child option. In that case replace the
+                    # config value of the parent with the value of the child
+                    option_value = config[option_name]
+                    parent_name = opt.parent_option_name
 
-                        if is_parent_reg:
-                            mes = f'Option {kparent} is not taken by parent plugin.'
-                            assert kparent in parent_class.takes_config.keys(), mes
-
-                        p.config[kparent] = v
-                    else:
-                        raise ValueError(f'You specified plugin {p.__class__.__name__} as a child plugin.'
-                                         f' Found the option {k} with the ending {p.child_ends_with}'
-                                         ' which was not specified as a child option.'
-                                         ' Was this intended? If yes, please change the ending')
+                    mes = (f'Cannot find "{parent_name}" among the options of the parent.'
+                           f' Either you specified by accident {option_name} as child option' 
+                           f' or you specified the wrong parent_option_name. Have you specified '
+                           'the correct parent option name?')
+                    assert parent_name in p.config, mes
+                    p.config[parent_name] = option_value
 
 
     def _get_plugins(self,
@@ -442,7 +441,7 @@ class Context:
             for pc in self._plugin_class_registry.values()])
         for k in self.config:
             if not (k in all_opts or k in self.context_config['free_options']):
-                warnings.warn(f"Option {k} not taken by any registered plugin")
+                warnings.warn(f"Option {k} not taken by any registered plugin", UserWarning, 2)
 
         # Initialize plugins for the entire computation graph
         # (most likely far further down than we need)
@@ -469,17 +468,29 @@ class Context:
 
             last_provide = d_provides
 
-            if p.child_ends_with:
+            if p.child_plugin:
                 # Plugin is a child of another plugin, hence we have to
                 # drop the parents config from the lineage
                 configs = {}
-                for q, v in p.config.items():
-                    if q + p.child_ends_with in p.takes_config:
-                        continue
-                    elif p.takes_config[q].track:
-                        configs[q] = v
-                # Adding parent information to the lineage:
+
+                # Getting information about the parent:
                 parent_class = p.__class__.__bases__[0]
+                # Get all parent options which are overwritten by a child:
+                parent_options = [option.parent_option_name for option in p.takes_config.values()
+                                  if option.child_option]
+
+                for option_name, v in p.config.items():
+                    # Looping over all settings, option_name is either the option name of the
+                    # parent or the child.
+                    if option_name in parent_options:
+                        # In case it is the parent we continue
+                        continue
+
+                    if p.takes_config[option_name].track:
+                        # Add all options which should be tracked:
+                        configs[option_name] = v
+
+                # Also adding name and version of the parent to the lineage:
                 configs[parent_class.__name__] = parent_class.__version__
                         
                 p.lineage = {last_provide: (p.__class__.__name__,
@@ -764,15 +775,31 @@ class Context:
     def estimate_run_start(self, run_id, targets=None):
         """Return run start time in ns since epoch.
 
+        This fetches from run metadata, and if this fails, it
+        estimates it using data metadata from targets.
+        """
+        warnings.warn('This function is outdated and will be removed in '
+                      'one of the feature strax releases. Please use '
+                      '"estimate_run_start_and_end" instead.', UserWarning)
+        start, _ = self.estimate_run_start_and_end(run_id, targets=targets)
+        return start
+
+    def estimate_run_start_and_end(self, run_id, targets=None):
+        """Return run start and end time in ns since epoch.
+
         This fetches from run metadata, and if this fails, it
         estimates it using data metadata from targets.
         """
         try:
-            # Use run metadata, if it is available, to get
-            # the run start time (floored to seconds)
-            t0 = self.run_metadata(run_id, 'start')['start']
-            t0 = t0.replace(tzinfo=datetime.timezone.utc)
-            return int(t0.timestamp()) * int(1e9)
+            res = []
+            for i in ('start', 'end'):
+                # Use run metadata, if it is available, to get
+                # the run start time (floored to seconds)
+                t = self.run_metadata(run_id, i)[i]
+                t = t.replace(tzinfo=datetime.timezone.utc)
+                t = int(t.timestamp()) * int(1e9)
+                res.append(t)
+            return res
         except (strax.RunMetadataNotAvailable, KeyError):
             pass
         # Get an approx start from the data itself,
@@ -781,36 +808,45 @@ class Context:
             for t in strax.to_str_tuple(targets):
                 try:
                     t0 = self.get_meta(run_id, t)['chunks'][0]['start']
-                    return (int(t0) // int(1e9)) * int(1e9)
+                    t0 = (int(t0) // int(1e9)) * int(1e9)
+
+                    t1 = self.get_meta(run_id, t)['chunks'][-1]['end']
+                    t1 = (int(t1) // int(1e9)) * int(1e9)
+                    return t0, t1
                 except strax.DataNotAvailable:
                     pass
         warnings.warn(
-            "Could not estimate run start time from "
-            "run metadata: assuming it is 0",
+            "Could not estimate run start and end time from "
+            "run metadata: assuming it is 0 and inf",
             UserWarning)
-        return 0
+        return 0, float('inf')
 
-
-    def to_absolute_time_range(self, run_id, targets, time_range=None,
-                               seconds_range=None, time_within=None):
+    def to_absolute_time_range(self, run_id, targets=None, time_range=None,
+                               seconds_range=None, time_within=None,
+                               full_range=None):
         """Return (start, stop) time in ns since unix epoch corresponding
         to time range.
 
+        :param run_id: run id to get
         :param time_range: (start, stop) time in ns since unix epoch.
         Will be returned without modification
         :param targets: data types. Used only if run metadata is unavailable,
         so run start time has to be estimated from data.
         :param seconds_range: (start, stop) seconds since start of run
         :param time_within: row of strax data (e.g. eent)
+        :param full_range: If True returns full time_range of the run.
         """
-        if ((time_range is None)
-                + (seconds_range is None)
-                + (time_within is None)
-                < 2):
+        
+        selection = ((time_range is None) +
+                     (seconds_range is None) +
+                     (time_within is None) +
+                     (full_range is None))
+        if selection < 2:
             raise RuntimeError("Pass no more than one one of"
-                               " time_range, seconds_range, ot time_within")
+                               " time_range, seconds_range, time_within"
+                               ", or full_range")
         if seconds_range is not None:
-            t0 = self.estimate_run_start(run_id, targets)
+            t0, _ = self.estimate_run_start_and_end(run_id, targets)
             time_range = (t0 + int(1e9 * seconds_range[0]),
                           t0 + int(1e9 * seconds_range[1]))
         if time_within is not None:
@@ -819,6 +855,9 @@ class Context:
             # Force time range to be integers, since float math on large numbers
             # in not precise
             time_range = tuple([int(x) for x in time_range])
+            
+        if full_range:
+            time_range = self.estimate_run_start_and_end(run_id, targets)
         return time_range
 
     def get_iter(self, run_id: str,
@@ -904,7 +943,9 @@ class Context:
                     chunks = self.get_meta(run_id, t)['chunks']
                     start_time = max(start_time, chunks[0]['start'])
                     end_time = min(end_time, chunks[-1]['end'])
-                except (strax.DataNotAvailable, KeyError):
+                except (strax.DataNotAvailable, KeyError, IndexError):
+                    # IndexError caused for only empty chunks when data not
+                    # available.
                     # Maybe at least one target had some metadata.
                     start_time = max(start_time, 0)
                     end_time = min(end_time, float('inf'))
@@ -939,7 +980,12 @@ class Context:
                     
                     if progress_bar:
                         # Update progressbar:
-                        pbar.n = (result.end - start_time) / (end_time - start_time)
+                        if end_time - start_time > 0:
+                            pbar.n = (result.end - start_time) / (end_time - start_time)
+                        else:
+                            # Strange, start and endtime are the same, probably we 
+                            # don't have data yet e.g. allow_incomplete == True.
+                            pbar.n = 0
                         pbar.update(0)
                         # Now get last time printed and refresh seconds_per_chunk:
                         # This is a small work around since we do not know the
@@ -1293,13 +1339,10 @@ class Context:
             # noinspection PyMethodFirstArgAssignment
             self = self.new_context(**kwargs)
 
-        key = self.key_for(run_id, target)
         for sf in self.storage:
-            try:
-                sf.find(key, **self._find_options)
+            if self._is_stored_in_sf(run_id, target, sf):
                 return True
-            except strax.DataNotAvailable:
-                continue
+        # None of the frontends has the data
         return False
 
     def _check_forbidden(self):
@@ -1331,6 +1374,104 @@ class Context:
             data = function(data, targets)
         return data
 
+    def copy_to_frontend(self, run_id, target,
+                         target_frontend_id=None, rechunk=False):
+        """
+        Copy data from one frontend to another
+        :param run_id: run_id
+        :param target: target datakind
+        :param target_frontend_id: index of the frontend that the data should go to
+        in context.storage. If no index is specified, try all.
+        :param rechunk: allow re-chunking for saving
+        """
+        if not self.is_stored(run_id, target):
+            raise strax.DataNotAvailable(f'Cannot copy {run_id} {target} since it '
+                                         f'does not exist')
+        if len(strax.to_str_tuple(target)) > 1:
+            raise ValueError(
+                'copy_to_frontend only works for a single target at the time')
+        if target_frontend_id is None:
+            target_sf = self.storage
+        elif len(self.storage) > target_frontend_id:
+            # only write to selected other frontend
+            target_sf = [self.storage[target_frontend_id]]
+        else:
+            raise ValueError(f'Cannot select {target_frontend_id}-th frontend as '
+                             f'we only have {len(self.storage)} frontends!')
+
+        # Figure out which of the frontends has the data. Raise error when none
+        source_sf = self._get_source_sf(run_id, target, should_exist=True)
+
+        # Keep frontends that:
+        #  1. don't already have the data; and
+        #  2. take the data; and
+        #  3. are not readonly
+        target_sf = [t_sf for t_sf in target_sf if
+                     (not self._is_stored_in_sf(run_id, target, t_sf) and
+                      t_sf._we_take(target) and
+                      t_sf.readonly is False)]
+
+        if not len(target_sf):
+            raise ValueError('No frontend to copy to! Perhaps you already stored '
+                             'it or none of the frontends is willing to take it?')
+
+        # Get the info from the source backend (s_be) that we need to fill
+        # the target backend (t_be) with
+        data_key = self.key_for(run_id, target)
+        # This should never fail, we just tried
+        s_be_str, s_be_key = source_sf.find(data_key)
+        s_be = source_sf._get_backend(s_be_str)
+        md = s_be.get_metadata(s_be_key)
+
+        for t_sf in target_sf:
+            try:
+                # Need to load a new loader each time since it's a generator
+                # and will be exhausted otherwise.
+                loader = s_be.loader(s_be_key)
+                # Fill the target buffer
+                t_be_str, t_be_key = t_sf.find(data_key, write=True)
+                target_be = t_sf._get_backend(t_be_str)
+                saver = target_be._saver(t_be_key, md)
+                saver.save_from(loader, rechunk=rechunk)
+            except NotImplementedError:
+                # Target is not susceptible
+                continue
+            except strax.DataExistsError:
+                raise strax.DataExistsError(
+                    f'Trying to write {data_key} to {t_sf} which already exists, '
+                    'do you have two storage frontends writing to the same place?')
+
+    def _is_stored_in_sf(self, run_id, target,
+                         storage_frontend: strax.StorageFrontend) -> bool:
+        """
+        :param run_id, target: run_id, target
+        :param storage_frontend: strax.StorageFrontend to check if it has the
+        requested datakey for the run_id and target.
+        :return: if the frontend has the key or not.
+        """
+        key = self.key_for(run_id, target)
+        try:
+            storage_frontend.find(key, **self._find_options)
+            return True
+        except strax.DataNotAvailable:
+            return False
+
+    def _get_source_sf(self, run_id, target, should_exist=False):
+        """
+        Get the source storage frontend for a given run_id and target
+        :param run_id, target: run_id, target
+        :param should_exist: Raise a ValueError if we cannot find one
+        (e.g. we already checked the data is stored)
+        :return: strax.StorageFrontend or None (when raise_error is
+        False)
+        """
+        for sf in self.storage:
+            if self._is_stored_in_sf(run_id, target, sf):
+                return sf
+        if should_exist:
+            raise ValueError('This cannot happen, we just checked that this '
+                             'run should be stored?!?')
+
     @classmethod
     def add_method(cls, f):
         """Add f as a new Context method"""
