@@ -8,7 +8,7 @@ import numpy as np
 
 __all__ = ('interval_dtype raw_record_dtype record_dtype hit_dtype peak_dtype '
            'DIGITAL_SUM_WAVEFORM_CHANNEL DEFAULT_RECORD_LENGTH '
-           'time_fields time_dt_fields').split()
+           'time_fields time_dt_fields hitlet_dtype hitlet_with_data_dtype').split()
 
 DIGITAL_SUM_WAVEFORM_CHANNEL = -1
 DEFAULT_RECORD_LENGTH = 110
@@ -75,6 +75,8 @@ def record_dtype(samples_per_record=DEFAULT_RECORD_LENGTH):
           'baseline'), np.float32),
         (('Baseline RMS in ADC counts. data = baseline - data_orig',
           'baseline_rms'), np.float32),
+        (('Multiply data by 2**(this number). Baseline is unaffected.',
+          'amplitude_bit_shift'), np.int16),
         (('Waveform data in raw counts above integer part of baseline',
           'data'), np.int16, samples_per_record),
     ]
@@ -88,6 +90,10 @@ hit_dtype = interval_dtype + [
         'left'), np.int16),
     (('Index of first sample in record just beyond hit (exclusive bound)',
         'right'), np.int16),
+    (('For lone hits, index of sample in record where integration starts',
+      'left_integration'), np.int16),
+    (('For lone hits, index of first sample beyond integration region',
+      'right_integration'), np.int16),
     (('Internal (temporary) index of fragment in which hit was found',
         'record_i'), np.int32),
     (('ADC threshold applied in order to find hits',
@@ -97,6 +103,56 @@ hit_dtype = interval_dtype + [
 ]
 
 
+def hitlet_dtype(n_widths=11):
+    """
+    Hitlet dtype same as peaklet or peak dtype but for hit-kind of
+    objects.
+    """
+    dtype = interval_dtype + [
+        (('Original length of the hit interval in samples',
+          'hit_length'), np.int32),
+        (('Total hit area in pe',
+          'area'), np.float32),
+        (('Maximum of the PMT pulse in pe/sample',
+          'amplitude'), np.float32),
+        (('Position of the Amplitude in ns (minus "time")',
+          'time_amplitude'), np.int16),
+        (('Hit entropy',
+          'entropy'), np.float32),
+        (('Peak widths in range of central area fraction in ns',
+          'width'), np.float32, n_widths),
+        (('Peak widths: time between nth and 5th area decile in ns',
+          'area_decile_from_midpoint'), np.float32, n_widths),
+        (('FWHM of the PMT pulse in ns',
+          'fwhm'), np.float32),
+        (('Left edge of the FWHM in ns (minus "time")',
+          'left'), np.float32),
+        (('FWTM of the PMT pulse in ns', 'fwtm'),
+         np.float32),
+        (('Left edge of the FWTM in ns (minus "time")',
+          'low_left'), np.float32),
+        (('Fragment index in which hit was found (hitlets can be in more than 1 fragment)',
+          'record_i'), np.int32)]
+    return dtype
+
+def hitlet_with_data_dtype(n_samples, n_widths=11):
+    """
+    Hitlet dtype with data field. Required within the plugins to compute
+    hitlet properties. 
+    
+    :param n_samples: Buffer length of the data field. Make sure it can
+        hold the longest hitlet.
+    :param n_widths: Number of area deciles width.
+
+    Note:
+        The data buffer will be at least 2 samples long
+    """
+    dtype = hitlet_dtype(n_widths)
+    n_samples = max(n_samples, 2)
+    return dtype + [(('Hitlet data in PE/sample with ZLE (only the first length samples are filled)', 'data'),
+                         np.float32, n_samples)]
+
+
 def peak_dtype(n_channels=100, n_sum_wv_samples=200, n_widths=11):
     """Data type for peaks - ranges across all channels in a detector
     Remember to set channel to -1 (todo: make enum)
@@ -112,8 +168,7 @@ def peak_dtype(n_channels=100, n_sum_wv_samples=200, n_widths=11):
           'area'), np.float32),
         (('Integral per channel [PE]',
           'area_per_channel'), np.float32, n_channels),
-        (("Number of hits from which peak was constructed "
-          "(currently zero if peak is split afterwards)",
+        (("Number of hits contributing at least one sample to the peak ",
           'n_hits'), np.int32),
         (('Waveform data in PE/sample (not PE/ns!)',
           'data'), np.float32, n_sum_wv_samples),
@@ -122,7 +177,7 @@ def peak_dtype(n_channels=100, n_sum_wv_samples=200, n_widths=11):
         (('Peak widths: time between nth and 5th area decile [ns]',
           'area_decile_from_midpoint'), np.float32, n_widths),
         (('Does the channel reach ADC saturation?',
-          'saturated_channel'), np.int16, n_channels),
+          'saturated_channel'), np.int8, n_channels),
         (('Total number of saturated channels',
           'n_saturated_channels'), np.int16),
         (('Hits within tight range of mean',
