@@ -218,6 +218,13 @@ def get_single_hitlet_data(hitlet, records, prev_r, next_r):
             r = records[prev_r_i]
             data, (p_start_i, end) = _get_thing_data(hitlet, r)
             if not end:
+                # If end is zero this means we have not found any
+                # overlap which should not have happened. In case of an
+                # overlap start and end should reflect the start and end
+                # sample of the hitlet for which we found data.
+                print('Data found for this record:', data,
+                      'Start index', p_start_i,
+                      'End index:', end)
                 raise ValueError('This is odd found previous record, but no'
                                  ' overlapping indices.')
             temp_data[p_start_i:data_start] = data
@@ -244,6 +251,13 @@ def get_single_hitlet_data(hitlet, records, prev_r, next_r):
             r = records[next_r_i]
             data, (start, p_end_i) = _get_thing_data(hitlet, r)
             if not start:
+                # If start is zero this means we have not found any
+                # overlap which should not have happened. In case of an
+                # overlap start and end should reflect the start and end
+                # sample of the hitlet for which we found data.
+                print('Data found for this record:', data,
+                      'Start index', start,
+                      'End index:', p_end_i)
                 raise ValueError('This is odd found the next record, but no'
                                  ' overlapping indicies.')
             temp_data[data_end:p_end_i] = data
@@ -343,29 +357,30 @@ def hitlet_properties(hitlets):
     Computes additional hitlet properties such as amplitude, FHWM, etc.
     """
     for h in hitlets:
-
         dt = h['dt']
         data = h['data'][:h['length']]
-        # Compute amplitude
-        amp_ind = np.argmax(data)
-        amp_time = int(amp_ind * dt)
-        height = data[amp_ind]
+        
+        if np.any(data):
+            # Compute amplitude
+            amp_ind = np.argmax(data)
+            amp_time = int(amp_ind * dt)
+            height = data[amp_ind]
 
-        h['amplitude'] = height
-        h['time_amplitude'] = amp_time
+            h['amplitude'] = height
+            h['time_amplitude'] = amp_time
 
-        # Computing FWHM:
-        left_edge, right_edge = get_fwxm(h, 0.5)
-        width = right_edge - left_edge
+            # Computing FWHM:
+            left_edge, right_edge = get_fwxm(h, 0.5)
+            width = right_edge - left_edge
 
-        # Computing FWTM:
-        left_edge_low, right_edge = get_fwxm(h, 0.1)
-        width_low = right_edge - left_edge_low
+            # Computing FWTM:
+            left_edge_low, right_edge = get_fwxm(h, 0.1)
+            width_low = right_edge - left_edge_low
 
-        h['fwhm'] = width
-        h['left'] = left_edge
-        h['low_left'] = left_edge_low
-        h['fwtm'] = width_low
+            h['fwhm'] = width
+            h['left'] = left_edge
+            h['low_left'] = left_edge_low
+            h['fwtm'] = width_low
 
 
 @export
@@ -388,31 +403,36 @@ def get_fwxm(hitlet, fraction=0.5):
         right last sample + 1.
     """
     data = hitlet['data'][:hitlet['length']]
-    max_val = hitlet['amplitude'] * fraction
 
     index_maximum = np.argmax(data)
-    pre_max = data[:index_maximum]
-    post_max = data[1 + index_maximum:]
+    max_val = data[index_maximum] * fraction
+    if np.all(data > max_val) or np.all(data == 0):
+        # In case all samples are larger, FWXM is not definition.
+        return np.nan, np.nan
 
-    # First the left edge:
-    lbi, lbs = _get_fwxm_boundary(pre_max, max_val)  # coming from the left
-    if lbi == NO_FWXM:
-        # We have not found any sample below:
-        left_edge = 0.
-    else:
-        # We found a sample below so lets compute
-        # the left edge:
+    pre_max = data[:index_maximum]  # Does not include maximum
+    post_max = data[1 + index_maximum:]  # same
+
+    if len(pre_max) and np.any(pre_max <= max_val):
+        # First the left edge:
+
+        lbi, lbs = _get_fwxm_boundary(pre_max[::-1], max_val)  # Reversing data starting at sample
+        # before maximum and go left
+        lbi = (index_maximum - 1) - lbi  # start sample minus samples we went to the left
         m = data[lbi + 1] - lbs  # divided by 1 sample
-        left_edge = lbi + (max_val - lbs) / m + 0.5  # .5 to start from bin center
-
-        # Now the right edge:
-    rbi, rbs = _get_fwxm_boundary(post_max[::-1], max_val)  # coming from the right
-    if rbi == NO_FWXM:
-        right_edge = len(data)
+        left_edge = lbi + (max_val - lbs) / m + 0.5
     else:
-        rbi = len(data) - rbi
-        m = data[rbi - 2] - rbs
-        right_edge = rbi - (max_val - data[rbi - 1]) / m - 0.5
+        # There is no data before the maximum:
+        left_edge = 0
+
+    if len(post_max) and np.any(post_max <= max_val):
+        # Now the right edge:
+        rbi, rbs = _get_fwxm_boundary(post_max, max_val)  # Starting after maximum and go right
+        rbi += 1 + index_maximum  # sample to the right plus start
+        m = data[rbi - 1] - rbs
+        right_edge = rbi - (max_val - rbs) / m + 0.5
+    else:
+        right_edge = len(data)
 
     left_edge = left_edge * hitlet['dt']
     right_edge = right_edge * hitlet['dt']
@@ -423,15 +443,22 @@ def get_fwxm(hitlet, fraction=0.5):
 def _get_fwxm_boundary(data, max_val):
     """
     Returns sample position and height for the last sample which
-    amplitude is below the specified value
+    amplitude is below the specified value.
+
+    If no sample can be found returns position and value of last sample
+    seen.
+
+    Note:
+        For FWHM we assume that we start at the maximum.
     """
-    i = NO_FWXM
-    s = NO_FWXM
-    for ind, d in enumerate(data):
+    ind = None
+    s = None
+    for i, d in enumerate(data):
         if d <= max_val:
-            i = ind
+            ind = i
             s = d
-    return i, s
+            return ind, s
+    return len(data)-1, data[-1]
 
 @export
 def conditional_entropy(hitlets, template='flat', square_data=False):
@@ -482,7 +509,11 @@ def conditional_entropy(hitlets, template='flat', square_data=False):
 def _conditional_entropy(hitlets, template, flat=False, square_data=False):
     res = np.zeros(len(hitlets), dtype=np.float32)
     for ind, h in enumerate(hitlets):
-        hitlet = h['data'][:h['length']]
+        # h['data'][:] generates just a view and not a copy of the data
+        # Since the data of hitlets should not be modified we have
+        # to use a copy instead.... See also https://stackoverflow.com/questions/4370745/view-onto-a-numpy-array
+        hitlet = np.copy(h['data'][:h['length']])
+
         # Squaring and normalizing:
         if square_data:
             hitlet[:] = hitlet * hitlet
