@@ -19,7 +19,11 @@ import pandas as pd
 # Change numba's caching backend from pickle to dill
 # I'm sure they don't mind...
 # Otherwise we get strange errors while caching the @growing_result functions
-numba.caching.pickle = dill
+try:
+    numba.core.caching.pickle = dill
+except AttributeError:
+    # Numba < 0.49
+    numba.caching.pickle = dill
 
 
 def exporter(export_self=False):
@@ -201,7 +205,6 @@ def profile_threaded(filename):
         monitoring_gil = True
     except (RuntimeError, ImportError):
         monitoring_gil = False
-        pass
 
     yappi.start()
     yield
@@ -221,7 +224,7 @@ def profile_threaded(filename):
 @export
 def to_str_tuple(x) -> ty.Tuple[str]:
     if isinstance(x, str):
-        return x,
+        return (x,)
     elif isinstance(x, list):
         return tuple(x)
     elif isinstance(x, tuple):
